@@ -1,6 +1,6 @@
 package String::Cluster::Hobohm;
 {
-  $String::Cluster::Hobohm::VERSION = '0.112890';
+  $String::Cluster::Hobohm::VERSION = '0.121330';
 }
 
 # ABSTRACT: Cluster strings using the Hobohm algorithm
@@ -67,7 +67,7 @@ sub _similarity {
     my $distance = Text::LevenshteinXS::distance(@seqs);
     defined $distance or croak "unable to compute distance";
 
-    return 1 - $distance / length( $seqs[0] );
+    return 1 - $distance / (length( $seqs[0] ) || 1);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -82,7 +82,7 @@ String::Cluster::Hobohm - Cluster strings using the Hobohm algorithm
 
 =head1 VERSION
 
-version 0.112890
+version 0.121330
 
 =head1 SYNOPSIS
 
@@ -137,10 +137,9 @@ The data structure returned after clustering would be:
 
     [ [ \'foo', \'foa' ], [ \'bar' ] ];
 
-The reason to use references instead of the actual strings is to avoid
-copying potentially large strings and taking up too much memory
-(remember that the algorithm was designed with biological sequences in
-mind).
+The reason for using references instead of the actual strings is to avoid
+copying potentially large strings and taking up too much memory (remember that
+the algorithm was designed with biological sequences in mind).
 
 =head1 REFERENCES
 
@@ -154,7 +153,7 @@ Bruno Vecchi <vecchi.b gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Bruno Vecchi.
+This software is copyright (c) 2012 by Bruno Vecchi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
